🔖 [Table of Contents](../README.md) / [Oops, I Did It Again](README.md)

# Oops, I Did It Again: The Most Common Mistakes When Working with Zrb

Collection of the most common mistakes when working with Zrb (You are not that innocent 😏)

[![Oops I Did It Again](https://img.youtube.com/vi/CduA0TULnow/0.jpg)](https://www.youtube.com/watch?v=CduA0TULnow)


- [Not Registering A Task to A Runner](not-registering-a-task-to-a-runner.md)
- [Defining Different Tasks With The Same Name Under The Same Group](defining-different-tasks-with-the-same-name-under-the-same-group.md)
- [Using The Same Variable to Define Different Task](using-the-same-variable-to-define-different-task.md)


🔖 [Table of Contents](../README.md) / [Oops, I Did It Again](README.md)